#######################################################################
#                                                                     #
#                                 Pph                                 #
#                                                                     #
#                    The Portable Project Handler                     #
#                                                                     #
#                  projet Estime, INRIA-Rocquencourt                  #
#                                                                     #
#  Copyright 2005-2011 INRIA.                                         #
#  Institut National de Recherche en Informatique et en Automatique.  #
#  All rights reserved. This file is distributed only by permission.  #
#                                                                     #
#  Francois Clement <Francois.Clement@inria.fr>                       #
#  Pierre Weis <Pierre.Weis@inria.fr>                                 #
#                                                                     #
#######################################################################

# $Id: configure_parsing.profile,v 1.10 2011-05-06 11:58:40 fclement Exp $

#
# Pph system configuration parsing.
# Used by user and devel configuration profiles ``configure.profile''.
#

CONFIGURE_OPTIONS="$@"

while test $# -gt 0; do
    
    case "$1" in
    
    # Installation root directory name.
    ( --install-root-dir | -install-root-dir | -ird | --prefix | -prefix )
        VAL=`expand "$2"`; shift
        # Perform sanity check.
        verify_nonempty "The installation root directory name" "$VAL"
        IER=$?
        if test $IER -ne 0; then exit $IER; fi
        INSTALL_ROOT_DIR_FROM_COMMAND_LINE="$VAL"
        ;;
        
    # Compilers.
    ( --c-compiler | -c-compiler | -cc )
        VAL=`expand "$2"`; shift
        C_COMPILER_FROM_COMMAND_LINE="$VAL"
        ;;
    ( --cpp-compiler | -cpp-compiler | -cppc )
        VAL=`expand "$2"`; shift
        CPP_COMPILER_FROM_COMMAND_LINE="$VAL"
        ;;
    ( --fortran-compiler | -fortran-compiler | -fc )
        VAL=`expand "$2"`; shift
        FORTRAN_COMPILER_FROM_COMMAND_LINE="$VAL"
        ;;
    ( --java-compiler | -java-compiler | -jc )
        VAL=`expand "$2"`; shift
        JAVA_COMPILER_FROM_COMMAND_LINE="$VAL"
        ;;
    ( --moca-compiler | -moca-compiler | -mc )
        VAL=`expand "$2"`; shift
        MOCA_COMPILER_FROM_COMMAND_LINE="$VAL"
        ;;
    ( --ocaml-byte-compiler | -ocaml-byte-compiler | -obc )
        VAL=`expand "$2"`; shift
        OCAML_BYT_COMPILER_FROM_COMMAND_LINE="$VAL"
        ;;
    ( --ocaml-native-compiler | -ocaml-native-compiler | -onc )
        VAL=`expand "$2"`; shift
        OCAML_BIN_COMPILER_FROM_COMMAND_LINE="$VAL"
        ;;
    ( --ocaml-command-search-path | -ocaml-command-search-path | -ocsp )
        VAL=`expand "$2"`; shift
        OCAML_COMMAND_SEARCH_PATH_FROM_COMMAND_LINE="$VAL"
        ;;
        
    # Preprocessors.
    ( --c-preprocessor | -c-preprocessor | -cpp )
        VAL=`expand "$2"`; shift
        C_PREPROCESSOR_FROM_COMMAND_LINE="$VAL"
        ;;
    ( --cpp-preprocessor | -cpp-preprocessor | -cpppp )
        VAL=`expand "$2"`; shift
        CPP_PREPROCESSOR_FROM_COMMAND_LINE="$VAL"
        ;;
    ( --fortran-preprocessor | -fortran-preprocessor | -fpp )
        VAL=`expand "$2"`; shift
        FORTRAN_PREPROCESSOR_FROM_COMMAND_LINE="$VAL"
        ;;
    ( --ocaml-preprocessor | -ocaml-preprocessor | -opp )
        VAL=`expand "$2"`; shift
        OCAML_PREPROCESSOR_FROM_COMMAND_LINE="$VAL"
        ;;
        
    # Operating modes.
    ( --verbosity-level | -verbosity-level | -vl )
        VAL=`expand "$2"`; shift
        VERBOSITY_LEVEL=$VAL
        ;;
    ( --debug | -debug | -d)
        VERBOSITY_LEVEL=$DEBUG_LEVEL
        DEBUG=true
        ;;
    ( --report | -report | -r)
        VERBOSITY_LEVEL=$REPORT_LEVEL
        REPORT=true
        ;;
    ( --summary | -summary | -s)
        VERBOSITY_LEVEL=$SUMMARY_LEVEL
        SUMMARY=true
        ;;
    ( --trace | -trace | -x)
        set -x
        ;;
    ( --see-you | -see-you | -n )
        VERBOSITY_LEVEL=$DEBUG_LEVEL
        SEE_YOU=true
        ;;
        
    # Help.
    ( --help | -help | -h )
        usage
        exit 0
        ;;
        
    # Unknown option name.
    ( -* )
        error "unknown option name \"$1\""
        remedy ""
        exit $UNKNOWN_OPTION_NAME_ERROR
        ;;
        
    # Invalid argument.
    ( * )
        error "invalid argument \"$1\""
        remedy ""
        exit $INVALID_ARGUMENT_ERROR
        ;;
        
    esac
    
    shift
    
done
