(* Camlp4 sklml syntax extension *)

open Camlp4

let mk_ident =
  let i = ref 0 in
  (fun () -> incr i; "__skl_expor_" ^ string_of_int !i)

module Id = struct
  let name = "pa_skl"
  let version = "1.0"
end

module Make(Syntax : Sig.Camlp4Syntax) = struct
  open Sig
  include Syntax

  let rec expr_of_list = function
  | [] -> invalid_arg "empty expression list"
  | [e] -> e
  | e :: t ->
    let _loc = Ast.loc_of_expr e in
    <:expr< $e$; $expr_of_list t$ >>

  let expors = ref []

  EXTEND Gram
    GLOBAL: expr str_item;

    str_item: FIRST
    [ [ x = NEXT ->
        let declist = !expors @ [x] in
        expors := []; Ast.stSem_of_list declist ] ]
    ;
    expr:
    [ [ "skl"; p = patt; "->"; el = LIST1 expr SEP ";" ->
        let ident = mk_ident () in
        let f = <:expr< function $p$ -> $expr_of_list el$ >> in
        expors :=
          <:str_item<
            let $lid:ident$ =
              let $lid:ident$ x = Sklstream.map ($f$ x) in
              ignore (Expor.register ($lid:ident$));
              fun x ->
                match Expor.is_registered $lid:ident$ with
                | Some rc -> atom (x, rc)
                | None -> assert false >> :: !expors;
        <:expr< $lid:ident$ >> ] ]
    ;
  END
end

let module M = Register.OCamlSyntaxExtension(Id)(Make) in ()
